@@ -666,19 +666,14 @@ int docmd_y_pow_x(arg_struct *arg) {
         return ERR_INVALID_TYPE;
     } else if (stack[sp]->type == TYPE_REAL) {
         phloat x = ((vartype_real *) stack[sp])->x;
-        if (x == floor(x)) {
+        if (x == to_int4(x)) {
             /* Integer exponent */
             if (stack[sp - 1]->type == TYPE_REAL) {
                 /* Real number to integer power */
                 phloat y = ((vartype_real *) stack[sp - 1])->x;
-                if (x == 0 && y == 0)
+                if (y == 0 && x <= 0)
                     return ERR_INVALID_DATA;
                 phloat r = pow(y, x);
-                if (p_isnan(r))
-                    /* Should not happen; pow() is supposed to be able
-                     * to raise negative numbers to integer exponents
-                     */
-                    return ERR_INVALID_DATA;
                 if ((inf = p_isinf(r)) != 0) {
                     if (!flags.f.range_error_ignore)
                         return ERR_OUT_OF_RANGE;
@@ -688,8 +683,68 @@ int docmd_y_pow_x(arg_struct *arg) {
                 goto done;
             } else {
                 /* Complex number to integer power */
-                phloat rre, rim, yre, yim;
-                int4 ex;
+                phloat yre = ((vartype_complex *) stack[sp - 1])->re;
+                phloat yim = ((vartype_complex *) stack[sp - 1])->im;
+                int4 ex = to_int4(x);
+
+                if (yim == 0) {
+                    /* Pure real base */
+                    if (yre == 0 && ex <= 0)
+                        return ERR_INVALID_DATA;
+                    phloat r = pow(yre, ex);
+                    if ((inf = p_isinf(r)) != 0) {
+                        if (!flags.f.range_error_ignore)
+                            return ERR_OUT_OF_RANGE;
+                        r = inf < 0 ? NEG_HUGE_PHLOAT : POS_HUGE_PHLOAT;
+                    }
+                    res = new_complex(r, 0);
+                    goto done;
+                } else if (yre == 0) {
+                    /* Pure imaginary base */
+                    phloat r = pow(yim, ex);
+                    if ((inf = p_isinf(r)) != 0) {
+                        if (!flags.f.range_error_ignore)
+                            return ERR_OUT_OF_RANGE;
+                        r = inf < 0 ? NEG_HUGE_PHLOAT : POS_HUGE_PHLOAT;
+                    }
+                    switch (ex & 3) {
+                        case 0: res = new_complex( r,  0); break;
+                        case 1: res = new_complex( 0,  r); break;
+                        case 2: res = new_complex(-r,  0); break;
+                        case 3: res = new_complex( 0, -r); break;
+                    }
+                    goto done;
+                }
+
+                bool invert = ex < 0;
+                if (invert)
+                    ex = -ex;
+                phloat rre, rim;
+
+                if (yre == yim || yre == -yim) {
+                    /* (a±ai)^n => pure real, pure imaginary, or r±ri */
+#ifdef BCD_MATH
+                    phloat r = pow(yre * yre * 2, ex / 2);
+                    if (ex % 2 != 0)
+                        r *= yre;
+#else
+                    phloat r = scalbn(pow(yre, ex), ex / 2);
+#endif
+                    switch (ex % 8) {
+                        case 0: rre =  r; rim =  0; break;
+                        case 1: rre =  r; rim =  r; break;
+                        case 2: rre =  0; rim =  r; break;
+                        case 3: rre = -r; rim =  r; break;
+                        case 4: rre = -r; rim =  0; break;
+                        case 5: rre = -r; rim = -r; break;
+                        case 6: rre =  0; rim = -r; break;
+                        case 7: rre =  r; rim = -r; break;
+                    }
+                    if (yre != yim)
+                        rim = -rim;
+                    goto complex_pow_int_done;
+                }
+
                 if (x < -256.0 || x > 256.0)
                     /* At some point, the cumulative error in repeated squaring
                      * becomes larger than the error in the polar power
@@ -699,20 +754,11 @@ int docmd_y_pow_x(arg_struct *arg) {
                      * return exact results for short bases, i.e. bases where
                      * first and last nonzero digits are close together. The
                      * smallest non-trivial base is 1+i, which can be raised to
-                     * the power 225 in the decimal version, and to the power
-                     * 107 in the binary version, with exact results.
+                     * the power 225 in the decimal version with exact results.
                      */
                     goto complex_pow_real_1;
                 rre = 1;
                 rim = 0;
-                yre = ((vartype_complex *) stack[sp - 1])->re;
-                yim = ((vartype_complex *) stack[sp - 1])->im;
-                ex = to_int4(x);
-                if (ex <= 0 && yre == 0 && yim == 0)
-                    return ERR_INVALID_DATA;
-                bool invert = ex < 0;
-                if (invert)
-                    ex = -ex;
                 while (1) {
                     phloat tmp;
                     if ((ex & 1) != 0) {
@@ -736,10 +782,11 @@ int docmd_y_pow_x(arg_struct *arg) {
                     if (p_isinf(yre) || p_isnan(yre) || p_isinf(yim) || p_isnan(yim))
                         goto complex_pow_real_1;
                 }
+                complex_pow_int_done:
                 if (invert) {
-                    phloat h = hypot(rre, rim);
-                    rre = rre / h / h;
-                    rim = (-rim) / h / h;
+                    int err = math_inv(rre, rim, &rre, &rim);
+                    if (err != ERR_NONE)
+                        return err;
                 }
                 if ((inf = p_isinf(rre)) != 0) {
                     if (!flags.f.range_error_ignore)
