@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Free42 -- an HP-42S calculator simulator
- * Copyright (C) 2004-2024  Thomas Okken
+ * Copyright (C) 2004-2025  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -888,7 +888,10 @@ int docmd_fma(arg_struct *arg) {
 }
 
 int docmd_func(arg_struct *arg) {
-    return push_func_state(arg->val.num);
+    int err = push_func_state(arg->val.num);
+    if (err == ERR_NONE)
+        print_stack_trace();
+    return err;
 }
 
 int docmd_errmsg(arg_struct *arg) {
@@ -995,6 +998,36 @@ int docmd_a2pline(arg_struct *arg) {
     return a2line(true);
 }
 
+int docmd_lock(arg_struct *arg) {
+    return prgm_lock(true);
+}
+
+int docmd_unlock(arg_struct *arg) {
+    return prgm_lock(false);
+}
+
+int docmd_ident(arg_struct *arg) {
+    const char *platform = shell_platform();
+    int len = 0;
+    while (platform[len] != 0 && platform[len] != ' ')
+        len++;
+
+    char vbuf[16];
+    memcpy(vbuf, platform, len);
+    vbuf[len] = 0;
+    int vcomp[4] = { 0, 0, 0, 0 };
+    sscanf(vbuf, "%d.%d.%d", &vcomp[0], &vcomp[1], &vcomp[2]);
+    char c = vbuf[len - 1];
+    if (c >= 'a')
+        vcomp[3] = c - 'a' + 1;
+    int ver = ((vcomp[0] * 100 + vcomp[1]) * 100 + vcomp[2]) * 100 + vcomp[3];
+
+    vartype *v = new_real(ver);
+    if (v == NULL)
+        return ERR_INSUFFICIENT_MEMORY;
+    return recall_result(v);
+}
+
 int docmd_rcomplx(arg_struct *arg) {
     bool p = flags.f.polar;
     flags.f.polar = 0;
@@ -1710,7 +1743,10 @@ static int concat(bool extend) {
             arg_struct arg;
             arg.type = ARGTYPE_STK;
             arg.val.stk = 'X';
+            char saved_trace = flags.f.trace_print;
+            flags.f.trace_print = 0;
             docmd_arcl(&arg);
+            flags.f.trace_print = saved_trace;
             text = reg_alpha;
             len = reg_alpha_length;
         }
