@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Free42 -- an HP-42S calculator simulator
- * Copyright (C) 2004-2024  Thomas Okken
+ * Copyright (C) 2004-2025  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -404,6 +404,12 @@ int p_isnan(Phloat p) {
     return r;
 }
 
+int p_isnormal(Phloat p) {
+    int r;
+    bid128_isNormal(&r, &p.val);
+    return r;
+}
+
 int to_digit(Phloat p) {
     BID_UINT128 ten, res;
     int d10 = 10;
@@ -752,6 +758,12 @@ Phloat scalbn(Phloat x, int y) {
     return Phloat(res);
 }
 
+Phloat copysign(Phloat x, Phloat y) {
+    BID_UINT128 res;
+    bid128_copySign(&res, &x.val, &y.val);
+    return Phloat(res);
+}
+
 Phloat operator*(int x, Phloat y) {
     BID_UINT128 xx, res;
     bid128_from_int32(&xx, &x);
