@@ -36,9 +36,9 @@ int hp2ascii(char *dst, const char *src, int srclen) {
             // Escape sequence: euro sign plus two hex digits.
             // In hp2ascii(), only used for undefined characters;
             // in ascii2hp(), accepted for everything.
-            dst[d++] = 0xe2;
-            dst[d++] = 0x82;
-            dst[d++] = 0xac;
+            dst[d++] = (char) 0xe2;
+            dst[d++] = (char) 0x82;
+            dst[d++] = (char) 0xac;
             dst[d++] = "0123456789abcdef"[c >> 4];
             dst[d++] = "0123456789abcdef"[c & 15];
             continue;
